@@ -551,7 +551,11 @@ class Convert:
 
     @staticmethod
     def rasterToGeoDataFrame(
-        src: str, vector: Union[str, GeoDataFrame] = None, add_geometry: str = None
+        src: str,
+        vector: Union[str, GeoDataFrame] = None,
+        add_geometry: str = None,
+        tile: bool = False,
+        tile_size: int = 1500,
     ) -> Union[DataFrame, GeoDataFrame]:
         """Convert a raster to a GeoDataFrame.
 
@@ -570,6 +574,10 @@ class Convert:
         add_geometry: [str]
             "Polygon", or "Point" if you want to add a polygon geometry of the cells as  column in dataframe.
             Default is None.
+        tile: [bool]
+            True to use tiles in extracting the values from the raster. Default is False.
+        tile_size: [int]
+            tile size. Default is 1500.
 
         Returns
         -------
@@ -605,14 +613,18 @@ class Convert:
             rasterized_vector: Dataset = Convert.polygonToRaster(
                 new_vector_path, src, vector_field="burn_value"
             )  # rasterized_vector_path,
-            coords = Raster.getCellPolygons(rasterized_vector, mask=True)
+            if add_geometry:
+                if add_geometry.lower() == "point":
+                    coords = Raster.getCellPoints(rasterized_vector, mask=True)
+                else:
+                    coords = Raster.getCellPolygons(rasterized_vector, mask=True)
 
             # Loop over mask values to extract pixels.
             # DataFrames of each tile.
             df_list = []
             mask_arr = rasterized_vector.GetRasterBand(1).ReadAsArray()
 
-            for arr in Raster.getTile(src):
+            for arr in Raster.getTile(src, tile_size):
 
                 mask_dfs = []
                 for mask_val in gdf["burn_value"].values:
@@ -636,25 +648,37 @@ class Convert:
             # Merge all the tiles.
             out_df = pd.concat(df_list)
         else:
-            # No vector given, simply load the raster.
-            df_list = []  # DataFrames of each tile.
-            for arr in Raster.getTile(src):
-                # Assume multiband
-                idx = (1, 2)
-                if arr.ndim == 2:
-                    # Handle single band rasters
-                    idx = (0, 1)
+            if tile:
+                df_list = []  # DataFrames of each tile.
+                for arr in Raster.getTile(src):
+                    # Assume multiband
+                    idx = (1, 2)
+                    if arr.ndim == 2:
+                        # Handle single band rasters
+                        idx = (0, 1)
 
-                mask_arr = np.ones((arr.shape[idx[0]], arr.shape[idx[1]]))
-                pixels = getPixels(arr, mask_arr).transpose()
-                df_list.append(pd.DataFrame(pixels, columns=band_names))
+                    mask_arr = np.ones((arr.shape[idx[0]], arr.shape[idx[1]]))
+                    pixels = getPixels(arr, mask_arr).transpose()
+                    df_list.append(pd.DataFrame(pixels, columns=band_names))
 
-            # Merge all the tiles.
-            out_df = pd.concat(df_list)
-            coords = Raster.getCellPolygons(src, mask=False)
+                # Merge all the tiles.
+                out_df = pd.concat(df_list)
+            else:
+                # Warning: not checked yet for multi bands
+                arr = src.ReadAsArray()
+                pixels = arr.flatten()
+                out_df = pd.DataFrame(pixels, columns=band_names)
+
+            if add_geometry:
+                if add_geometry.lower() == "point":
+                    coords = Raster.getCellPoints(src, mask=True)
+                else:
+                    coords = Raster.getCellPolygons(src, mask=True)
 
         out_df = out_df.drop(columns=["burn_value", "geometry"], errors="ignore")
-        out_df_with_geoms = gpd.GeoDataFrame(out_df, geometry=coords["geometry"])
+        if add_geometry:
+            out_df = gpd.GeoDataFrame(out_df, geometry=coords["geometry"])
+
         # TODO mask no data values.
 
         # Remove temporary files.
@@ -662,7 +686,7 @@ class Convert:
             shutil.rmtree(temp_dir, ignore_errors=True)
 
         # Return dropping any extra cols.
-        return out_df_with_geoms
+        return out_df
 
     @staticmethod
     def _ogrDataSourceToGeoDF(ds: DataSource) -> GeoDataFrame:
